..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

API Docs
========

Extension
---------
.. automodule:: invenio_userprofiles.ext
   :members:

Admin
-----

.. automodule:: invenio_userprofiles.admin
   :members:

API
---

.. automodule:: invenio_userprofiles.api
   :members:


Models
------

.. automodule:: invenio_userprofiles.models
   :members:

Forms
-----

.. automodule:: invenio_userprofiles.forms
   :members:

Validators
----------

.. automodule:: invenio_userprofiles.validators
   :members:

Views
-----

.. automodule:: invenio_userprofiles.views
   :members:
